![Cluster API driver for Magnum](docs/static/logo.png?raw=true "Cluster API driver for Magnum")

The Cluster API driver for Magnum allows you to deploy fully conformant
Kubernetes cluster using the [Cluster API](https://cluster-api.sigs.k8s.io/)
project which are fully integrated with the OpenStack cluster they are running
on.

For more information, please refer to the following resources:

* **Documentation**: https://vexxhost.github.io/magnum-cluster-api/
* **Community**: [`#magnum-cluster-api`](https://kubernetes.slack.com/archives/C05Q8TDTK6Z) channel
  on the Kubernetes Slack. If you are new to Kubernetes Slack workspace,
  [Join the Kubernetes Slack workspace](https://slack.kubernetes.io/) first.

## Images

The Cluster API driver for Magnum relies on specific OpenStack images containing
all necessary dependencies for deploying Kubernetes clusters.

For more information on how to build images and where to find pre-built images,
refer to the [user guide](https://vexxhost.github.io/magnum-cluster-api/user/images/)

## Testing & Development

For more information on how to test, develop and contribute to the Cluster API
driver for Magnum, refer to the [developer guide](https://vexxhost.github.io/magnum-cluster-api/developer/testing-and-development/).
